@@ -420,10 +420,13 @@ def has_dulwich():
     "dulwich", "Dulwich >= %s", [
         '%d.%d.%d' % vers
         for vers in (
-            (0, 19, 10),
+            (0, 19, 7),
             (0, 20, 0),
             (0, 20, 3),
             (0, 20, 4),
+            (0, 20, 37),
+            (0, 20, 44),
+            (0, 21, 0),
         )
     ]
 )
@@ -1175,3 +1178,14 @@ def has_lzma():
 @check("bash", "bash shell")
 def has_bash():
     return matchoutput("bash -c 'echo hi'", b'^hi$')
+
+
+@check("unicodefs", "Unicode-only file system")
+def has_unicode_filesystem():
+    try:
+        with tempfile.NamedTemporaryFile(
+            prefix="bøf".encode("latin-1"), dir=b"."
+        ):
+            return False
+    except Exception:
+        return True
